/*-----------------------------------------------------------------------
landpop.do

Stata do file to re-create the tables and graph in the paper
'Decomposing the growth in residential land in the United States',
by Henry G. Overman, Diego Puga, and Matthew A. Turner.
-----------------------------------------------------------------------*/
#delimit;
clear;
set more off;
capture quietly log close;

log using landpop,text replace;

* area units: state, msa;
foreach units in state msa {;

  use landpop_`units', clear;

  /* define level variables */
  rename respix_1976 res_1976;
  rename respix_1992 res_1992;
  * residential land per person;
  gen double res_pp_1976 = res_1976/pop_1976;
  gen double res_pp_1992 = res_1992/pop_1992;
  * residential land per household;
  gen double res_ph_1976 = res_1976/hhds_1976;
  gen double res_ph_1992 = res_1992/hhds_1992;
  * households per person;
  gen double hhds_pp_1976 = hhds_1976/pop_1976;
  gen double hhds_pp_1992 = hhds_1992/pop_1992;
  * people per household;
  gen double pop_ph_1976 = pop_1976/hhds_1976;
  gen double pop_ph_1992 = pop_1992/hhds_1992;

  /* define absolute change variables */
  * change in residential land;
  gen double D_res = res_1992 - res_1976;
  * change in residential land per person;
  gen double D_res_pp = res_pp_1992 - res_pp_1976;
  * change in population;
  gen double D_pop = pop_1992 - pop_1976;
  * change in population at national rate;
  egen long us_pop_1976         = sum(pop_1976);
  egen long us_pop_1992         = sum(pop_1992);
  gen double D_pop_usrate = ((us_pop_1992 - us_pop_1976)/us_pop_1976) * pop_1976;
  drop us_pop_1976 us_pop_1992;
  * differential change in population;
  gen double D_pop_diffus = D_pop - D_pop_usrate;
  * change in residential land per household;
  gen double D_res_ph = res_ph_1992 - res_ph_1976;
  * change in household size (households/people);
  gen double D_hhd_pp = hhds_pp_1992 - hhds_pp_1976;

  /* define percentage change variables */
  gen Dpc_res = 100*(res_1992 - res_1976)/res_1976;
  gen Dpc_pop = 100*(pop_1992 - pop_1976)/pop_1976;
  gen Dpc_res_pp = 100*(res_pp_1992 - res_pp_1976)/res_pp_1976;
  gen Dpc_pop_ph = 100*(pop_ph_1992 - pop_ph_1976)/pop_ph_1976;

  /* define components of decompositions */
  * contribution of changes in population;
  gen double dec_D_pop = D_pop * res_pp_1976;
  * contribution of changes in residential land per person;
  gen double dec_D_res_pp = D_res_pp * pop_1976;
  * contribution of interactions land per person - population;
  gen double dec_Irespop = D_res_pp * D_pop;
  * contribution of changes in national population;
  gen double dec_D_pop_usrate = D_pop_usrate * res_pp_1976;
  * contribution of differential changes in population;
  gen double dec_D_pop_diffus = D_pop_diffus * res_pp_1976;
  * contribution of changes in residential land per household;
  gen double dec_D_res_pp_res_phh = pop_1976 * D_res_ph * hhds_pp_1976;
  * contribution of changes in household sizes;
  gen double dec_D_res_pp_hhd_pp = pop_1976 * res_ph_1976 * D_hhd_pp;
  * contribution of interactions land per household - household size;
  gen double dec_D_res_pp_I = pop_1976 * D_res_ph * D_hhd_pp;
  * contribution of interactions;
  gen double dec_D_I = dec_Irespop + dec_D_res_pp_I;

  /* list decompositions in the text */
  if ("`units'" == "state") {;
    preserve;
    * prepare 1st decomposition;
    keep if `units' == 0;
    * express decomposition components in percentage;
    replace dec_D_pop = 100 * dec_D_pop / D_res;
    replace dec_D_res_pp = 100 * dec_D_res_pp / D_res;
    replace dec_Irespop = 100 * dec_Irespop / D_res;
    * show 1st decomposition;
    format dec_* %9.1f;
    list dec_D_pop dec_D_res_pp dec_Irespop, abbreviate(16);
    restore;
    * prepare 2nd and 3rd decompositions;
    preserve;
    drop if `units' == 0;
    collapse (sum) D_res dec_D_pop_usrate dec_D_pop_diffus dec_D_res_pp dec_Irespop dec_D_res_pp_res_phh dec_D_res_pp_hhd_pp dec_D_I;
    * express decomposition components in percentage;
    replace dec_D_pop_usrate = 100 * dec_D_pop_usrate / D_res;
    replace dec_D_pop_diffus = 100 * dec_D_pop_diffus / D_res;
    replace dec_D_res_pp = 100 * dec_D_res_pp / D_res;
    replace dec_Irespop = 100 * dec_Irespop / D_res;
    replace dec_D_res_pp_res_phh = 100 * dec_D_res_pp_res_phh / D_res;
    replace dec_D_res_pp_hhd_pp = 100 * dec_D_res_pp_hhd_pp / D_res;
    replace dec_D_I = 100 * dec_D_I / D_res;
    * show 2nd decomposition;
    format dec_* %9.1f;
    list dec_D_pop_usrate dec_D_pop_diffus dec_D_res_pp dec_Irespop, abbreviate(16);
    * show 3rd decomposition;
    list dec_D_pop_usrate dec_D_pop_diffus dec_D_res_pp_res_phh dec_D_res_pp_hhd_pp dec_D_I, abbreviate(16);
    restore;
  };

  /* generate latex tables */
  * national decomposition;
  if ("`units'" == "state") {;
    egen us_dec_D_pop_usrate = sum(dec_D_pop_usrate);
    egen us_dec_D_pop_diffus = sum(dec_D_pop_diffus);
    egen us_dec_D_res_pp_res_phh = sum(dec_D_res_pp_res_phh);
    egen us_dec_D_res_pp_hhd_pp = sum(dec_D_res_pp_hhd_pp);
    egen us_dec_D_I = sum(dec_D_I);
    replace dec_D_pop_usrate = us_dec_D_pop_usrate - dec_D_pop_usrate if `units' == 0;
    replace dec_D_pop_diffus = us_dec_D_pop_diffus - dec_D_pop_diffus if `units' == 0;
    replace dec_D_res_pp_res_phh = us_dec_D_res_pp_res_phh - dec_D_res_pp_res_phh if `units' == 0;
    replace dec_D_res_pp_hhd_pp = us_dec_D_res_pp_hhd_pp - dec_D_res_pp_hhd_pp if `units' == 0;
    replace dec_D_I = us_dec_D_I - dec_D_I if `units' == 0;
    drop us_dec_*;
  };
  * express population in millions;
  replace pop_1976 = pop_1976/1000000;
  * express land in square meters;
  replace res_pp_1976 = 900*res_pp_1976;
  * express decomposition components in percentage;
  replace dec_D_pop_usrate = 100 * dec_D_pop_usrate / D_res;
  replace dec_D_pop_diffus = 100 * dec_D_pop_diffus / D_res;
  replace dec_D_res_pp_res_phh = 100 * dec_D_res_pp_res_phh / D_res;
  replace dec_D_res_pp_hhd_pp = 100 * dec_D_res_pp_hhd_pp / D_res;
  replace  dec_D_I = 100 * dec_D_I/ D_res;
  * format for table;
  format *_1976 %9.2f;
  format Dpc_* dec_* %9.1f;
  gen str1 ampersand = "&";
  gen str4 slash = "\\";
  if ("`units'" == "state") {;
    * names for display;
    gen state_name_t = state_name;
    replace state_name_t = "\textsc{dc}" if state_ab == "DC";
    replace state_name_t = "N. Hampshire" if state_ab == "NH";
    replace state_name_t = "N. Dakota" if state_ab == "ND";
    replace state_name_t = "S. Dakota" if state_ab == "SD";
    replace state_name_t = "N. Carolina" if state_ab == "NC";
    replace state_name_t = "S. Carolina" if state_ab == "SC";
    * place national observation at bottom with \hline above this;
    gen orderobs = 0;
    local newobs = _N + 1;
    set obs `newobs';
    replace orderobs = 1 if missing(state_ab);
    replace state_name_t = "\hline" if orderobs == 1;
    replace orderobs = 2 if state_ab == "US";
    sort orderobs state_name;
    * output latex table;
    outsheet state_name_t ampersand Dpc_res ampersand Dpc_res_pp ampersand Dpc_pop ampersand Dpc_pop_ph ampersand res_pp_1976 ampersand pop_1976 ampersand pop_ph_1976 slash using t_state_stats.tex, nonames noquote replace;
    outsheet state_name_t ampersand dec_D_pop_usrate ampersand dec_D_pop_diffus ampersand dec_D_res_pp_res_phh ampersand dec_D_res_pp_hhd_pp ampersand dec_D_I slash using t_state_decom.tex, nonames noquote replace;
  };
  else {;
    * names for display;
    gen str20 msa_name_t=substr(msa_name,1,strpos(msa_name,",")-1);
    replace msa_name_t=substr(msa_name_t,1,strpos(msa_name_t,"-")-1) if strpos(msa_name_t,"-")>0;
    replace msa_name_t = "Washington-Baltimore" if msa_name_t == "Washington";
    replace msa_name_t = "Minneapolis-St. Paul" if msa_name_t == "Minneapolis";
    sort msa_name_t;
    * output latex table;
    format sprawl_1976_92 %9.1f;
    outsheet msa_name_t ampersand Dpc_res ampersand Dpc_res_pp ampersand Dpc_pop ampersand Dpc_pop_ph ampersand res_pp_1976 ampersand pop_1976 ampersand pop_ph_1976 ampersand sprawl_1976_92 slash using t_msa_stats.tex if pop_1992 > 1000000 & msa < 10000, nonames noquote replace;
    outsheet msa_name_t ampersand dec_D_pop_usrate ampersand dec_D_pop_diffus ampersand dec_D_res_pp_res_phh ampersand dec_D_res_pp_hhd_pp ampersand dec_D_I slash using t_msa_decom.tex if pop_1992 > 1000000 & msa < 10000, nonames noquote replace;
    format sprawl_1976_92 Dpc_res_pp %9.0f;
    scatter sprawl_1976_92 Dpc_res_pp if pop_1992 > 1000000 & msa < 9999  & msa > 0 ,
    msymbol(o) msize(vsmall) mcolor(gs4) legend(off)
    mlabel(msa_name_t) mlabsize(vsmall) mlabposition(3)
    xlabel(-30 0 30 60 90, nogrid) ylabel(30 40 50 60 70 80 90, nogrid)
    ytitle("Scatteredness of 1976-92 development") xtitle("% change in residential land per person")
    ;
  };

};

log close;

exit;
